Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(88)

Unified Diff: components/web_view/frame_tree_delegate.h

Issue 1406153004: components/mus/public/interfaces View => Window (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Yet another rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/web_view/frame_tree.cc ('k') | components/web_view/public/cpp/web_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/web_view/frame_tree_delegate.h
diff --git a/components/web_view/frame_tree_delegate.h b/components/web_view/frame_tree_delegate.h
index 55be5612140a075e61f6ef82cc74ad7d5c2bbc51..7743828484fe7be47bd5bb03d86101aba8a4baa9 100644
--- a/components/web_view/frame_tree_delegate.h
+++ b/components/web_view/frame_tree_delegate.h
@@ -9,7 +9,7 @@
#include "base/callback_forward.h"
#include "base/memory/scoped_ptr.h"
-#include "components/mus/public/interfaces/view_tree.mojom.h"
+#include "components/mus/public/interfaces/window_tree.mojom.h"
#include "components/web_view/public/interfaces/frame.mojom.h"
#include "mojo/services/network/public/interfaces/url_loader.mojom.h"
#include "url/gurl.h"
@@ -31,7 +31,7 @@ class FrameTreeDelegate {
base::Callback<void(uint32_t,
mojom::FrameClient*,
scoped_ptr<FrameUserData>,
- mojo::ViewTreeClientPtr)>;
+ mus::mojom::WindowTreeClientPtr)>;
// Called when a Frame creates a new child Frame. |frame_tree_client| is the
// FrameClient for the new frame.
@@ -59,7 +59,7 @@ class FrameTreeDelegate {
// Asks the client if navigation is allowed. If the navigation is allowed
// |callback| should be called to continue the navigation. |callback|
// may be called synchronously or asynchronously. In the callback
// mojo::ViewTreeClientPtr should only be set if an app other than
// frame->app_id() is used to render |request|.
virtual void CanNavigateFrame(Frame* target,
mojo::URLRequestPtr request,
@@ -59,7 +59,7 @@ class FrameTreeDelegate {
// |callback| should be called to continue the navigation. |callback|
// may be called synchronously or asynchronously. In the callback
- // mojo::ViewTreeClientPtr should only be set if an app other than
+ // mus::mojom::WindowTreeClientPtr should only be set if an app other than
// frame->app_id() is used to render |request|.
virtual void CanNavigateFrame(Frame* target,
« no previous file with comments | « components/web_view/frame_tree.cc ('k') | components/web_view/public/cpp/web_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698